import React from 'react';
import {
    View,
    Text,
    Alert,
    PermissionAndroid,
    Platform,
    Modal,
    StyleSheet,
    TouchableOpacity,
} from 'react-native';
import RNAndroidLocationEnabler from 'react-native-android-location-enabler';
import {
    check,
    PERMISSIONS,
    RESULTS,
    request,
    openSettings,
} from 'react-native-permissions';
import GetLocation from 'react-native-get-location';
export default class Test extends React.Component {
    constructor(props) {
        super(props)
        this.state = {
            modalVisible: false,
            backgroundColor: 'white',
            location: null
        }
    }
    componentDidMount() {
        this.checkLocation();
    }
    showModal = () => {
        return (
            <Modal
                animationType="slide"
                transparent={true}
                visible={this.state.modalVisible}
                onRequestClose={() => {
                    Alert.alert('Modal has been closed.');
                    this.setState({ modalVisible: !this.state.modalVisible })
                }}>
                <View style={styles.centeredView}>
                    <View style={styles.modalView}>
                        <View style={{ paddingHorizontal: 20, marginBottom: 20 }}>
                            <Text
                                style={{
                                    color: 'grey',
                                    textAlign: 'center',
                                    fontWeight: 'bold',
                                    // fontFamily: fonts.Futura_Book_Font,
                                    fontSize: 20,
                                    marginBottom: 10,
                                }}>
                                Location Permission Denied
              </Text>
                            <Text
                                style={{
                                    textAlign: 'center',
                                    color: 'grey',
                                    // fontFamily: fonts.Futura_Book_Font,
                                    fontSize: 16,
                                }}>
                                Turning on Location Permission can help you keep up to date.
              </Text>
                        </View>
                        <View
                            style={{
                                height: 0.5,
                                width: '100%',
                                backgroundColor: 'grey',
                                opacity: 0.2,
                            }}
                        />
                        <View
                            style={{
                                flexDirection: 'row',
                                height: 60,
                                width: '100%',
                                alignItems: 'center',
                                justifyContent: 'space-evenly',
                            }}>
                            <TouchableOpacity
                                onPress={() => {
                                    openSettings();
                                    this.setState({ modalVisible: !this.state.modalVisible })
                                }}>
                                <Text style={{ color: 'blue' }}>Settings</Text>
                            </TouchableOpacity>
                            <View
                                style={{
                                    backgroundColor: 'grey',
                                    height: '100%',
                                    width: 1,
                                    opacity: 0.5,
                                }}
                            />
                            <TouchableOpacity
                                onPress={() => {
                                    this.setState({ modalVisible: !this.state.modalVisible })
                                }}>
                                <Text
                                    style={{
                                        // textAlign: 'center',
                                        color: 'blue',
                                        width: '100%',
                                    }}>
                                    Cancel
                </Text>
                            </TouchableOpacity>
                        </View>
                    </View>
                </View>
            </Modal>
        );
    };
    getDeviceLocation = async () => {
        await GetLocation.getCurrentPosition({
            enableHighAccuracy: true,
            timeout: 15000,
        })
            .then((location) => {
                if (location) {
                    this.setState({ location: location })

                    alert('Device Location is' + JSON.stringify(this.state.location));
                    this.setState({ backgroundColor: 'pink' })
                }
            })
            .catch((err) => {
                console.log(err);
                this.setState({ backgroundColor: 'green' })
            });
    };
    checkLocation = async () => {
        try {
            if (Platform.OS == 'android') {
                RNAndroidLocationEnabler.promptForEnableLocationIfNeeded({
                    interval: 10000,
                    fastInterval: 5000,
                }).then((data) => {
                    console.log('Enable location data', data);
                    alert('Enable location data', data);
                    this.getDeviceLocation();
                });
            } else {
                check(PERMISSIONS.IOS.LOCATION_WHEN_IN_USE).then((result1) => {
                    check(PERMISSIONS.IOS.LOCATION_ALWAYS).then((result2) => {
                        console.log('result ==>', result1, result2);
                        if (result1 == 'granted' && result2 == 'blocked') {
                            this.getDeviceLocation();
                        } else if (result1 == 'blocked' && result2 == 'granted') {
                            this.getDeviceLocation();
                        } else if (result1 == 'denied' && result2 == 'denied') {
                            this.getDeviceLocation();
                        } else {
                            this.setState({ modalVisible: true })
                        }
                    });
                });
            }
        } catch (error) {
            console.log('Error==>', error);
        }
    };

    render() {
        return (
            <View style={{ alignSelf: 'center', alignItems: 'center', height: '100%', width: '100%', justifyContent: 'center', flexDirection: 'row', backgroundColor: this.state.backgroundColor }}>
                <Text style={{ alignSelf: 'center', textAlign: 'center' }}>Location: {JSON.stringify(this.state.location)}</Text>
                {this.showModal()}
            </View>
        );
    }
}
const styles = StyleSheet.create({
    centeredView: {
        flex: 1,
        padding: 44,
        justifyContent: 'center',
        alignItems: 'center',
        width: '100%',
    },
    modalView: {
        borderRadius: 10,
        backgroundColor: 'white',
        width: '100%',
        justifyContent: 'center',
        alignItems: 'center',
        marginTop: 20,
        marginBottom: 20,
        // margin: 20,
        paddingTop: 20,
        shadowColor: '#000',
        shadowOffset: {
            width: 0,
            height: 2,
        },
        shadowOpacity: 0.25,
        shadowRadius: 4,
    },
});